<ul> 
    <li>Блоки перемещаются &mdash; перетаскиванием.</li>
    <li>При перемещении, добавлении или удалении блоков страницы, необходимо сохранение всей страницы.</li>
    <li>Если вы удалили какой-то блок случайно. <br>Можно вернуться к сохраненной версии,
    перезагрузив страницу. При этом все отредактированные блоки сохранятся, но сортировка будет взята из сохраненной версии. Новые добавленные объекты так же не сохранятся.</li>
</ul>